@@ -1,49 +1,36 @@
-
-from mewpy.utils.ode import KineticConfigurations, SolverConfigurations, ODEStatus, ODESpySolver
-from mewpy.simulation.simulation import SimulationResult
-from mewpy.model.kinetic import ODEModel
-from collections import OrderedDict
 import threading
+from collections import OrderedDict
 import warnings
+from ..simulation.simulation import SimulationResult
+from ..model.kinetic import ODEModel
+from ..solvers import KineticConfigurations, SolverConfigurations, ODEStatus, ode_solver_instance
 
 
-def kinetic_solve(model, finalParameters, finalFactors, initialConc, timePoints):
-    """
-    Private function: auxiliary function required to avoid the pickling the solver.solve function
+def kinetic_solve(model, y0, time_steps, parameters=None, factors=None):
 
-    """
-    finalRates = OrderedDict()
-    f = model.get_ode(r_dict=finalRates, params=finalParameters, factors=finalFactors)
+    rates = OrderedDict()
+    f = model.get_ode(r_dict=rates, params=parameters, factors=factors)
+    solver = ode_solver_instance(f, KineticConfigurations.SOLVER_METHOD)
 
-    def func(x, t):
-        return f(t, x)
+    C, t, X = solver.solve(y0, time_steps)
 
-    solver = ODESpySolver(KineticConfigurations.SOLVER_METHOD).get_solver(func)
-    solver.set_initial_condition(list(initialConc.values()))
-    try:
-        X, _ = solver.solve(timePoints)
-        # if solver returns a solution where any concentration is negative
-        for c in X[1]:
-            if c < -1*SolverConfigurations.RELATIVE_TOL:
-                return ODEStatus.ERROR, {}, {}
-
-    except Exception as e:
-        warnings.warn(f"ODE Solver error: {e}.")
-        return ODEStatus.ERROR, {}, {}
+    for c in C:
+        if c < -1 * SolverConfigurations.RELATIVE_TOL:
+            return ODEStatus.ERROR, {}, {}
 
     # values bellow solver precision will be set to 0
-    finalRates.update({k: 0 for k, v in finalRates.items() if
-                       v < SolverConfigurations.ABSOLUTE_TOL and v > - SolverConfigurations.ABSOLUTE_TOL})
-    conc = OrderedDict(zip(model.metabolites.keys(), X[1]))
-    return ODEStatus.OPTIMAL, finalRates, conc
+    rates.update({k: 0 for k, v in rates.items() if
+                  v < SolverConfigurations.ABSOLUTE_TOL and v > - SolverConfigurations.ABSOLUTE_TOL})
+    conc = OrderedDict(zip(model.metabolites.keys(), C))
+    return ODEStatus.OPTIMAL, rates, conc
 
 
 class KineticThread(threading.Thread):
     """
     Solves the ODE inside a thread enabling to impose a timeout limit with thread.join(timeout)
-
     """
-    def __init__(self, model, parameters=None, final_factors=None, initial_concentrations=None, time_steps=None):
+
+    def __init__(self, model, initial_concentrations=None, time_steps=None, parameters=None, final_factors=None):
         super(KineticThread, self).__init__()
         self.model = model
         self.parameters = parameters
@@ -56,16 +43,18 @@ class KineticThread(threading.Thread):
 
     def run(self):
         try:
-            self.status, self.rates, self.concentrations = kinetic_solve(self.model, self.parameters,
-                                                                         self.final_factors,
+            self.status, self.rates, self.concentrations = kinetic_solve(self.model,
                                                                          self.initial_concentrations,
-                                                                         self.time_steps)
+                                                                         self.time_steps,
+                                                                         self.parameters,
+                                                                         self.final_factors)
         except Exception as e:
             warnings.warn(f"{e}")
         return
 
 
 class kineticSimulationResult(SimulationResult):
+
     def __init__(self, model, status, factors=None, rates=None, concentrations=None):
         super(kineticSimulationResult, self).__init__(model, None, fluxes=rates, status=status)
         self.factors = factors
@@ -74,16 +63,13 @@ class kineticSimulationResult(SimulationResult):
 
 class KineticSimulation:
 
-    def __init__(self, model, parameters=None, tSteps=[0, 1e9], timeout=KineticConfigurations.SOLVER_TIMEOUT,
-                 solver=KineticConfigurations.SOLVER, method=KineticConfigurations.SOLVER_METHOD):
+    def __init__(self, model, parameters=None, tSteps=[0, 1e9], timeout=KineticConfigurations.SOLVER_TIMEOUT):
         if not isinstance(model, ODEModel):
             raise ValueError('model is not an instance of ODEModel.')
         self.model = model
         self.parameters = parameters
         self.tSteps = tSteps
         self.timeout = timeout
-        self.solver = solver
-        self.method = method
 
     def __getstate__(self):
         state = OrderedDict(self.__dict__.copy())
@@ -93,7 +79,13 @@ class KineticSimulation:
         self.__dict__.update(state)
 
     def get_initial_concentrations(self):
-        return self.model.concentrations
+        values = []
+        for i, m in enumerate(self.model.metabolites):
+            try:
+                values.append(self.model.concentrations[m])
+            except:
+                values.append(None)
+        return values
 
     def get_time_steps(self):
         return self.tSteps
@@ -105,12 +97,11 @@ class KineticSimulation:
 
         :param dict factores: Modification over the kinetic model.
         :returns: Returns a kineticSimulationResult with the steady-state flux distribution and concentrations.
-
         """
 
         final_factors = factors if factors is not None else {}
         # update initial concentrations when a [enz] is changed: == 0, up or down regulated
-        initConcentrations = self.get_initial_concentrations().copy()
+        initConcentrations = self.get_initial_concentrations()
 
         status = None
         sstateRates = None
@@ -125,15 +116,18 @@ class KineticSimulation:
 
             th.start()
             th.join(self.timeout)
+            if th.is_alive():
+                th.join()
             status = th.status
             sstateRates = th.rates
             sstateConc = th.concentrations
 
         else:
-            status, sstateRates, sstateConc = kinetic_solve(self.model, self.parameters,
-                                                            final_factors,
+            status, sstateRates, sstateConc = kinetic_solve(self.model,
                                                             initConcentrations,
-                                                            self.get_time_steps())
+                                                            self.get_time_steps(),
+                                                            self.parameters,
+                                                            final_factors)
 
         return kineticSimulationResult(self.model, status, factors=final_factors, rates=sstateRates,
                                        concentrations=sstateConc)
