@@ -1,5 +1,4 @@
-
-from collections import Iterable
+""" Adapted from Daniel Machado's REFRAMED"""
 from .solver import Solver, VarType, Parameter, default_parameters
 from .solution import Solution, Status
 from cplex import Cplex, infinity, SparsePair
@@ -106,6 +105,19 @@ class CplexSolver(Solver):
         self._cached_upper_bounds.update(dict(zip(var_ids, ubs)))
         self._cached_lin_obj.update({var_id: 0.0 for var_id in var_ids})
 
+    def set_variable_bounds(self, var_id, lb, ub):
+        """Modify a variable bounds
+
+        Args:
+            var_id (str): [description]
+            lb (float): lower bound
+            ub (float): upper bound
+        """
+        if lb:
+            self.problem.variables.set_lower_bounds(var_id, lb)
+        if ub:
+            self.problem.variables.set_upper_bounds(var_id, ub)
+
     def add_constraint(self, constr_id, lhs, sense='=', rhs=0, update=True):
         """ Add a constraint to the current problem.
 
@@ -334,10 +346,10 @@ class CplexSolver(Solver):
                 values, s_prices, r_costs = None, None, None
 
                 if get_values:
-                    if isinstance(get_values, Iterable):
+                    try:
                         get_values = list(get_values)
                         values = dict(zip(get_values, problem.solution.get_values(get_values)))
-                    else:
+                    except Exception:
                         values = dict(zip(self.var_ids, problem.solution.get_values()))
 
                 if shadow_prices:
@@ -435,10 +447,10 @@ class CplexSolver(Solver):
             obj = pool.get_objective_value(i)
 
             if get_values:
-                if isinstance(get_values, Iterable):
+                try:
                     get_values = list(get_values)
                     values = dict(zip(get_values, pool.get_values(i, get_values)))
-                else:
+                except Exception:
                     values = dict(zip(self.var_ids, pool.get_values(i)))
             else:
                 values = None
